@@ -120,7 +120,7 @@ class CFGGraph_java(CFGGraph):
                 dest_node,
             )
             logger.warning(traceback.format_stack()[-2])
-            print(src_node, dest_node, edge_type)
+            # print(src_node, dest_node, edge_type)
             raise NotImplementedError
         else:
             for src, dest, ty, *_ in self.CFG_edge_list:
@@ -193,7 +193,7 @@ class CFGGraph_java(CFGGraph):
         
         except Exception as e:
             # return 2, None
-            print("DO NOT IGNORE", e)
+            # print("DO NOT IGNORE", e)
             logger.warning(traceback.format_stack()[-2])
             raise NotImplementedError
             return next_node_index, next_node
@@ -869,7 +869,7 @@ class CFGGraph_java(CFGGraph):
                         pass
 
             elif current_node_type in self.statement_types["not_implemented"]:
-                print("WARNING: Not implemented ", current_node_type)
+                logger.warning("WARNING: Not implemented ", current_node_type)
                 warning_counter += 1
 
         self.get_basic_blocks(self.CFG_node_list, self.CFG_edge_list)
@@ -1405,5 +1405,5 @@ class CFGGraph_java(CFGGraph):
         
         self.add_method_call_edges()
         if warning_counter > 0:
-            print("Total number of warnings from unimplemented statement types: ", warning_counter)
+            logger.warning("Total number of warnings from unimplemented statement types: ", warning_counter)
         return self.CFG_node_list, self.CFG_edge_list
