@@ -10,6 +10,10 @@ class_declaration_statements = [
     "interface_declaration",
     "property_declaration",
     "class_declaration",
+    "field_declaration",
+    "struct_declaration",
+    "local_function_statement",
+    
 ]
 
 inner_node_type = [
@@ -20,6 +24,7 @@ inner_node_type = [
     # '_declaration',
     "labeled_statement",
     "expression_statement",
+    
 ] + scope_only_blocks
 non_control_statements = inner_node_type + class_declaration_statements
 loop_control_statements = ["for_each_statement", "while_statement", "for_statement"]
@@ -40,11 +45,22 @@ control_statements = loop_control_statements + [
     "try_statement",
     # 'try_with_resources_statement'
 ]
+statement_holders = [
+        "block",
+        # "switch_block_statement_group",
+        "switch_body",
+        "switch_section",
+        "declaration_list"
+        # "constructor_body",
+        # "declaration_list",
+        # "module_body",
+        # "program"
+    ]
 # based on handling simmilarity
 statement_types = {
     "node_list_type": non_control_statements
     + control_statements
-    + ["method_declaration"],
+    + ["method_declaration", "local_function_statement"],
     "scope_only_blocks": scope_only_blocks,
     "outer_node_type": ["for_statement"],
     "inner_node_type": inner_node_type,
@@ -55,8 +71,12 @@ statement_types = {
     "not_implemented": [
         # 'try_with_resources_statement'
     ],
+    "statement_holders": statement_holders,
+    "definition_types": ["method_declaration", "constructor_declaration", "class_declaration", "field_declaration", "interface_declaration", "operator_declaration", "conversion_operator_declaration"]
 }
 # TODO: add method_return_types
+method_return_types = ['integral_type', 'void_type', 'type_identifier', 'generic_type', 'scoped_type_identifier', 'floating_point_type', 'boolean_type', 'array_type']
+
 
 def cl(child):
     if child is None:
@@ -95,7 +115,86 @@ def return_index_of_first_parent_of_type(node, parent_type):
             return node.parent
         node = node.parent
     return None
+def get_signature(node):
+    signature = []
+    formal_parameters = node.child_by_field_name('parameters')
+    formal_parameters = list(filter(lambda x: x.type == 'parameter', formal_parameters.named_children))
+    # for formal_parameter in formal_parameters:
+    #     for child in formal_parameter.children:
+    #         if child.type != "identifier":
+    #             signature.append(child.text.decode('utf-8'))\
+    for formal_parameter in formal_parameters:
+        param_type = formal_parameter.child_by_field_name('type')
+        if param_type is None:
+            try:
+                param_type = list(filter(lambda x: x.type == 'identifier', formal_parameter.named_children))[0]
+                param_text = param_type.text.decode('utf-8')
+                if '[]' in param_text:
+                    param_text = param_text.split('[',1)
+                    param_text = " [".join(param_text)
+                signature.append(param_text)
+            except:
+                pass
+        else:
+            param_text = param_type.text.decode('utf-8')
+            if '[]' in param_text:
+                param_text = param_text.split('[',1)
+                # print(param_text)
+                param_text = " [".join(param_text)
+                # print(param_text)
+            signature.append(param_text)
 
+    return tuple(signature)
+
+def abstract_method(node):
+    method_body = get_child_of_type(node, ["block"])
+    while node is not None:
+        if node.type == "declaration_list" and node.parent.type == "class_declaration":
+            node = node.parent
+
+            modifiers = get_child_of_type(node, ["modifiers"])
+            if modifiers is not None and "abstract" in modifiers.text.decode("utf-8") and method_body is None:
+                return True
+        node = node.parent
+    return False
+def get_child_of_type(node, type_list):
+    out = list(filter(lambda x : x.type in type_list, node.children))
+    if len(out) > 0:
+        return out[0]
+    else: 
+        return None
+def get_class_name(node, index):
+    "Returns the class name when a method declaration or constructor declaration is passed to it"
+    type_identifiers = ["type_identifier", "generic_type", "scoped_type_identifier"]
+    while node is not None:
+        if node.type == "declaration_list" and node.parent.type == "class_declaration":
+            node = node.parent
+        
+            class_index = index[(node.start_point, node.end_point, node.type)]
+            class_name = [(list(filter(lambda child: child.type == "identifier", node.children))[0]).text.decode("UTF-8")]
+            
+            interface_node = get_child_of_type(node, ["super_interfaces"])
+            if interface_node is not None:
+                class_name.append(get_child_of_type(interface_node, ["type_list"]).text.decode("UTF-8"))
+
+            superclass_node = get_child_of_type(node, ["superclass"])
+            if superclass_node is not None:
+                class_name.append(get_child_of_type(superclass_node, ["type_identifier"]).text.decode("UTF-8"))
+
+            return class_index, class_name
+        
+        elif node.type == "declaration_list" and node.parent.type == "object_creation_expression":
+            node = node.parent
+            class_index = index[(node.start_point, node.end_point, node.type)]
+            class_name = [list(filter(lambda child: child.type in type_identifiers, node.children))[0].text.decode("UTF-8")]
+            return class_index, class_name
+        elif node.type == "interface_body" and node.parent.type == "interface_declaration":
+            return None
+            node = node.parent
+            class_index = index[(node.start_point, node.end_point, node.type)]
+            class_name = list(filter(lambda child: child.type == "identifier", node.children))[0]
+            return class_index, class_name.text.decode("UTF-8")
+        node = node.parent
 
 def get_nodes(root_node=None, node_list={}, graph_node_list=[], index={}, records={}):
     """
@@ -190,38 +289,76 @@ def get_nodes(root_node=None, node_list={}, graph_node_list=[], index={}, record
             # if-else ladder
             label = root_node.text.decode("UTF-8")
             type_label = "expression_statement"
+            # print(label, root_node.type)
             if root_node.type in [
                 "method_declaration",
                 "interface_declaration",
                 "constructor_declaration",
                 "property_declaration",
             ]:
+                # method_name = list(
+                #     filter(lambda child: child.type == "identifier", root_node.children)
+                # )
+                # parameter_list = list(
+                #     filter(
+                #         lambda child: child.type == "parameter_list", root_node.children
+                #     )
+                # )
+                # label = method_name[-1].text.decode("UTF-8")
+                # if parameter_list:
+                #     label = label + parameter_list[0].text.decode("UTF-8")
+                # type_label = root_node.type
+                # # ? make sure records is being updated for the newer updates if required
+                # records["method_list"][method_name[-1].text.decode("UTF-8")] = index[
+                #     root_node.start_point, root_node.end_point, root_node.type
+                # ]
+                # graph_node_list.append(
+                #     (
+                #         index[
+                #             (root_node.start_point, root_node.end_point, root_node.type)
+                #         ],
+                #         method_name[-1].start_point[0],
+                #         label,
+                #         type_label,
+                #     )
+                # )
+                label = ""
+                for child in root_node.children:
+                    if child.type != "block" and child.type != "constructor_body":
+                        label = label + " " + child.text.decode('utf-8')
                 method_name = list(
                     filter(lambda child: child.type == "identifier", root_node.children)
                 )
-                parameter_list = list(
-                    filter(
-                        lambda child: child.type == "parameter_list", root_node.children
-                    )
-                )
-                label = method_name[-1].text.decode("UTF-8")
-                if parameter_list:
-                    label = label + parameter_list[0].text.decode("UTF-8")
+                method_name = method_name[0].text.decode("UTF-8")
+                method_index = index[(root_node.start_point, root_node.end_point, root_node.type)]
                 type_label = root_node.type
-                # ? make sure records is being updated for the newer updates if required
-                records["method_list"][method_name[-1].text.decode("UTF-8")] = index[
-                    root_node.start_point, root_node.end_point, root_node.type
-                ]
-                graph_node_list.append(
-                    (
-                        index[
-                            (root_node.start_point, root_node.end_point, root_node.type)
-                        ],
-                        method_name[-1].start_point[0],
-                        label,
-                        type_label,
-                    )
-                )
+                try:
+                    signature = get_signature(root_node)
+                    class_index, class_name_list = get_class_name(root_node, index)
+                    if method_name == "Main":
+                        # print("Main method found")
+                        records["main_method"] = method_index
+                        records["main_class"] = class_index
+                    if abstract_method(root_node) == False:
+                        for class_name in class_name_list:
+                            if root_node.type == "constructor_declaration":
+                                if class_name == method_name:
+                                    records["constructor_list"][((class_name,method_name), signature)] = method_index
+                                return_type = None
+                            else:
+                                records["method_list"][((class_name,method_name), signature)] = method_index
+                                try:
+                                    return_type = list(filter(lambda child: child.type in method_return_types, root_node.children))
+                                    return_type = return_type[0].text.decode("UTF-8")
+                                except:
+                                    raise Exception("No return type found for method, update method_return_types", method_name)
+                            
+                            records["return_type"][((class_name,method_name), signature)] = return_type
+
+                except Exception as e:
+                    # print("*******", e)
+                    pass
+                graph_node_list.append((method_index, root_node.start_point[0],label,type_label))
             elif (
                 root_node.type == "class_declaration"
                 # or root_node.type == "constructor_declaration"
